Processor.App.OutStreamer.dummy\_streamer.DummyStreamer.\_\_init\_\_
====================================================================

.. currentmodule:: Processor.App.OutStreamer.dummy_streamer

.. automethod:: DummyStreamer.__init__